viqa.load\_utils.ImageArray
===========================

.. currentmodule:: viqa.load_utils

.. autoclass:: ImageArray

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ImageArray.__init__
      ~ImageArray.all
      ~ImageArray.any
      ~ImageArray.argmax
      ~ImageArray.argmin
      ~ImageArray.argpartition
      ~ImageArray.argsort
      ~ImageArray.astype
      ~ImageArray.byteswap
      ~ImageArray.choose
      ~ImageArray.clip
      ~ImageArray.compress
      ~ImageArray.conj
      ~ImageArray.conjugate
      ~ImageArray.copy
      ~ImageArray.cumprod
      ~ImageArray.cumsum
      ~ImageArray.describe
      ~ImageArray.diagonal
      ~ImageArray.dot
      ~ImageArray.dump
      ~ImageArray.dumps
      ~ImageArray.fill
      ~ImageArray.flatten
      ~ImageArray.getfield
      ~ImageArray.item
      ~ImageArray.itemset
      ~ImageArray.max
      ~ImageArray.mean
      ~ImageArray.min
      ~ImageArray.newbyteorder
      ~ImageArray.nonzero
      ~ImageArray.partition
      ~ImageArray.prod
      ~ImageArray.ptp
      ~ImageArray.put
      ~ImageArray.ravel
      ~ImageArray.repeat
      ~ImageArray.reshape
      ~ImageArray.resize
      ~ImageArray.round
      ~ImageArray.searchsorted
      ~ImageArray.setfield
      ~ImageArray.setflags
      ~ImageArray.sort
      ~ImageArray.squeeze
      ~ImageArray.std
      ~ImageArray.sum
      ~ImageArray.swapaxes
      ~ImageArray.take
      ~ImageArray.tobytes
      ~ImageArray.tofile
      ~ImageArray.tolist
      ~ImageArray.tostring
      ~ImageArray.trace
      ~ImageArray.transpose
      ~ImageArray.var
      ~ImageArray.view
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ImageArray.T
      ~ImageArray.base
      ~ImageArray.ctypes
      ~ImageArray.data
      ~ImageArray.dtype
      ~ImageArray.flags
      ~ImageArray.flat
      ~ImageArray.imag
      ~ImageArray.itemsize
      ~ImageArray.nbytes
      ~ImageArray.ndim
      ~ImageArray.real
      ~ImageArray.shape
      ~ImageArray.size
      ~ImageArray.strides
   
   